@@ -14,11 +14,13 @@
  * limitations under the License.
  */
 
+#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
- * @file gssapi/source/library/compare_name.c
+ * @file compare_name.c
  * @brief Globus GSI GSSAPI gss_compare_name
  * @author Sam Meder, Sam Lang
  */
+#endif
 
 #include "gssapi_openssl.h"
 #include "globus_i_gsi_gss_utils.h"
